Module parse_input

Module parse_input 

Structs

ParsedInput
Parsed input that can come from either the input argument or a GitHub URL

Enums

ParsedQuery
Query

Functions

try_parse_input
Parse user input into a structured query, optionally with an explicit repo URL.