Module resolution

Module resolution 

Query resolution logic.

This module contains the orchestration layer that resolves user queries to identified information using backend implementations. It also defines the types for representing resolved information.

Structs

EnrichedInfo
The enriched result of identification - progressively accumulates data
FileResult
For file results (special case with blame history)
IssueInfo
Information about an Issue

Enums

EntryPoint
What the user entered to search for
IdentifiedThing

Functions

resolve
Resolve a query to identified information using the provided backend.