pub struct GitRepo { /* private fields */ }Implementations
Sourceimpl GitRepo
impl GitRepo
Sourcepub fn find_commit(&self, hash_str: &str) -> Option<CommitInfo>
pub fn find_commit(&self, hash_str: &str) -> Option<CommitInfo>
Try to find a commit by hash (can be short or full)
Get all tags in the repository
Get all tags in the repository, enriched with GitHub release info
Expose tags that contain the specified commit.
Sourcepub fn tag_from_release(&self, release: &ReleaseInfo) -> Option<TagInfo>
pub fn tag_from_release(&self, release: &ReleaseInfo) -> Option<TagInfo>
Convert a GitHub release into tag metadata if the tag exists locally.
Sourcepub fn tag_contains_commit(
&self,
tag_commit_hash: &str,
commit_hash: &str,
) -> bool
pub fn tag_contains_commit( &self, tag_commit_hash: &str, commit_hash: &str, ) -> bool
Check whether a release tag contains the specified commit.
Sourcepub fn github_remote(&self) -> Option<(String, String)>
pub fn github_remote(&self) -> Option<(String, String)>
Get the GitHub remote URL if it exists (checks all remotes)