pub struct GitHubClient { /* private fields */ }Implementations
Sourceimpl GitHubClient
impl GitHubClient
Sourcepub async fn fetch_commit_info(
&self,
commit_hash: &str,
) -> Option<(String, String, Option<(String, String)>)>
pub async fn fetch_commit_info( &self, commit_hash: &str, ) -> Option<(String, String, Option<(String, String)>)>
Fetch the GitHub username and URLs for a commit Returns None if the commit doesn’t exist on GitHub
Sourcepub async fn fetch_pr(&self, number: u64) -> Option<PullRequestInfo>
pub async fn fetch_pr(&self, number: u64) -> Option<PullRequestInfo>
Try to fetch a PR
Sourcepub async fn fetch_issue(&self, number: u64) -> Option<IssueInfo>
pub async fn fetch_issue(&self, number: u64) -> Option<IssueInfo>
Try to fetch an issue
Sourcepub async fn fetch_releases(&self) -> Vec<ReleaseInfo>
pub async fn fetch_releases(&self) -> Vec<ReleaseInfo>
Fetch all releases from GitHub
Sourcepub async fn fetch_releases_since(
&self,
since_date: Option<&str>,
) -> Vec<ReleaseInfo>
pub async fn fetch_releases_since( &self, since_date: Option<&str>, ) -> Vec<ReleaseInfo>
Fetch releases from GitHub, optionally filtered by date
If since_date is provided, stop fetching releases older than this date
This significantly speeds up lookups for recent PRs/issues
Sourcepub async fn fetch_release_by_tag(&self, tag: &str) -> Option<ReleaseInfo>
pub async fn fetch_release_by_tag(&self, tag: &str) -> Option<ReleaseInfo>
Fetch a GitHub release by tag.
Sourcepub fn commit_url(&self, hash: &str) -> String
pub fn commit_url(&self, hash: &str) -> String
Build GitHub URLs for various things Build a commit URL (fallback when API data unavailable) Uses URL encoding to prevent injection
Sourcepub fn tag_url(&self, tag: &str) -> String
pub fn tag_url(&self, tag: &str) -> String
Build a tag URL (fallback when API data unavailable) Uses URL encoding to prevent injection
Sourcepub fn profile_url(username: &str) -> String
pub fn profile_url(username: &str) -> String
Build a profile URL (fallback when API data unavailable) Uses URL encoding to prevent injection