pub struct GitHubClient { /* private fields */ }Implementations
Sourceimpl GitHubClient
impl GitHubClient
Sourcepub const fn is_available(&self) -> bool
pub const fn is_available(&self) -> bool
Check if client is available
Fetch the GitHub username of a commit author Returns None if the commit doesn’t exist on GitHub or has no author
Sourcepub async fn fetch_pr(&self, number: u64) -> Option<PullRequestInfo>
pub async fn fetch_pr(&self, number: u64) -> Option<PullRequestInfo>
Try to fetch a PR
Sourcepub async fn fetch_issue(&self, number: u64) -> Option<IssueInfo>
pub async fn fetch_issue(&self, number: u64) -> Option<IssueInfo>
Try to fetch an issue
Sourcepub async fn fetch_releases(&self) -> Vec<ReleaseInfo>
pub async fn fetch_releases(&self) -> Vec<ReleaseInfo>
Fetch all releases from GitHub
Sourcepub async fn fetch_releases_since(
&self,
since_date: Option<&str>,
) -> Vec<ReleaseInfo>
pub async fn fetch_releases_since( &self, since_date: Option<&str>, ) -> Vec<ReleaseInfo>
Fetch releases from GitHub, optionally filtered by date
If since_date is provided, stop fetching releases older than this date
This significantly speeds up lookups for recent PRs/issues
Sourcepub async fn fetch_release_by_tag(&self, tag: &str) -> Option<ReleaseInfo>
pub async fn fetch_release_by_tag(&self, tag: &str) -> Option<ReleaseInfo>
Fetch a GitHub release by tag.
Sourcepub fn commit_url(&self, hash: &str) -> String
pub fn commit_url(&self, hash: &str) -> String
Build GitHub URLs for various things
pub fn release_url(&self, tag: &str) -> String
pub fn tag_url(&self, tag: &str) -> String
pub fn profile_url(username: &str) -> String
pub fn issue_url(&self, number: u64) -> String
pub fn pr_url(&self, number: u64) -> String