Module parse_input
wtg_cli
0.3.1
Module parse_
input
Module Items
Structs
Enums
Functions
In crate wtg_
cli
wtg_cli
Module
parse_
input
Structs

Parsed
Input
Parsed input that can come from either the input argument or a GitHub URL
Enums

Parsed
Query
Query
Functions

try_
parse_
input
Parse user input into a structured query, optionally with an explicit repo URL.