Query resolution logic.
This module contains the orchestration layer that resolves user queries to identified information using backend implementations. It also defines the types for representing resolved information.
Structs
- Enriched
Info - The enriched result of identification - progressively accumulates data
- File
Result - For file results (special case with blame history)
- Issue
Info - Information about an Issue
Enums
- Entry
Point - What the user entered to search for
- Identified
Thing
Functions
- resolve
- Resolve a query to identified information using the provided backend.