pub async fn resolve(
backend: &dyn Backend,
query: &Query,
filter: &ReleaseFilter,
) -> WtgResult<IdentifiedThing>Expand description
Resolve a query to identified information using the provided backend.
The filter parameter controls which releases are considered when finding
the release that contains a commit.